
/*****************************************************************************************/
//	DEMO SETUP

// This is just basic setup for the demo.
mob
	animate_movement = NO_STEPS

	Login()
		src.loc = locate("start")

	proc/SetText(message)
		winset(src, "label", "text=\"[message]\"")



/******************************************************************************************
	These are supporting functions for the trigger library. They make it possible to activate
	triggers by step in onto and off of them, and by bumping into them. This takes advantage
	of the different ways to work with triggers:
		- Stepping onto a trigger calls trigger.Activate(player)
		- Stepping off of a trigger calls trigger.Deactivate(player)
		- Bumping into a trigger calls trigger.Toggle(player)
*******************************************************************************************/

// When an atom enters a turf, it calls Activate() for every trigger in that turf.
turf/Entered(atom/movable/A)
	..()
	for(var/trigger/T in src.contents)
		T.Activate(A)

// When an atom exits a turf, it calls the Deactivate proc for every trigger in the turf.
// This provides an opportunity for triggers to undo the effects created when the trigger
// was stepped on.
turf/Exited(atom/movable/A)
	for(var/trigger/T in src.contents)
		T.Deactivate(A)
	..()

// When an object bumps into another object, if the bumped object is a turf, then it will
// toggle any triggers within the turf. Otherwise it will toggle any triggers within the
// location of the object that was bumped.
atom/movable/Bump(atom/A)
	..()
	A = isturf(A) ? A : A.loc
	for(var/trigger/T in A)
		T.Toggle(src)
	return




/*
Trigger examples to cover:

-Single Target Trigger
-Multi-Target Trigger
-Trigger with usage delay
-Weighted Triggers
-Multi-trigger target
Timed trigger
-Perma-trigger
-step-trigger
*/



/******************************************************************************************/
// Trigger and device examples.

trigger

	// A lever is a dense trigger that toggles when bumped into. When it
	// becomes active, it displays the lever facing right, and when disabled
	// it displays the lever facing left. The leverl also has a 2-tick
	// trigger_delay so that you won't flip it back and forth a million
	// times while walking into it.
	lever
		icon_state = "lever_left"
		density = 1
		opacity = 0
		trigger_delay = 2

		activated
			icon_state = "lever_right"
			trigger_active = 1
			// note that you need to set the trigger_active to true if you want to have a version
			// of the trigger that is already activated.

		Activated()
			icon_state = "lever_right"

		Deactivated()
			icon_state = "lever_left"


	// A step trigger is an invisible trigger that is activated when the
	// player steps in it, and deactivated when the player steps off agian.
	step_trigger
		invisibility = 100
		density = 0
		opacity = 0



/******************************************************************************************/
// This is the countdown loop that runs continually in the background for the purpose of
// this demo. The reason you're required to call Countdown() manually is because you may
// want to have your own game loops so that you can pause what's happening, including the
// countdown.

// In this demo, each number in the timer value is equal to 10 ticks, or 1 second. So if
// a trigger's trigger_timer = 5, you have 5 seconds before it will deactivate.

world/New()
	..()
	spawn()
		CountdownLoop()

proc/CountdownLoop()
	for()
		sleep(10)
		for(var/trigger/T in world)
			T.Countdown()



/******************************************************************************************/
// These are turf defenitions for all of the turfs which are used here.

atom
	icon = 'icons.dmi'

mob
	icon_state = "mob"
	density = 1
	opacity = 0


turf
	floor
		icon_state = "floor"
		density = 0
		opacity = 0

	wall
		icon_state = "wall"
		density = 1
		opacity = 1

	// Gates open and close with the use of levers.
	gate
		icon_state = "gate"
		density = 1
		opacity = 0

		gate_open
			icon_state = "door"
			density = 0

		Activated()
			icon_state = "door"
			density = 0
			world.log << "active"

		Deactivated()
			icon_state = "gate"
			density = 1
			world.log << "deactive"

	// Statues can be like secret passages that open and close.
	statue
		icon_state = "statue"
		density = 1
		opacity = 1

		Activate()
			icon_state = "floor"
			density = 0
			opacity = 0

		Deactivate()
			icon_state = "statue"
			density = 1
			opacity = 1

	window
		icon_state = "window"
		density = 1
		opacity = 0

	door
		icon_state = "door"
		density = 0
		opacity = 0

	grass
		icon_state = "grass"
		density = 0
		opacity = 0

	tree
		icon_state = "tree"
		density = 1
		opacity = 0

	// Info tiles display information on the interface when stepped
	// on, and remove that information when you step off.
	info
		density = 0
		opacity = 0
		var/message = ""
		Entered(mob/M)
			if(ismob(M))
				if(M.client)
					M.SetText(src.message)
		Exited(mob/M)
			if(ismob(M))
				if(M.client)
					M.SetText("")

		floor
			icon_state = "question"
		grass
			icon_state = "question2"


